← Back to team overview

widelands-dev team mailing list archive

[Merge] lp:~widelands-dev/widelands/string-fixes into lp:widelands

 

GunChleoc has proposed merging lp:~widelands-dev/widelands/string-fixes into lp:widelands.

Commit message:
Various string fixes for tribes

Requested reviews:
  Widelands Developers (widelands-dev)
Related bugs:
  Bug #1421942 in widelands: "Unified term for "Black" and "Wasteland""
  https://bugs.launchpad.net/widelands/+bug/1421942
  Bug #1487887 in widelands: "Translation missing in editor and in replay tooltip"
  https://bugs.launchpad.net/widelands/+bug/1487887
  Bug #1530240 in widelands: "wrong text in the tribal encyclopedia for the battle ax"
  https://bugs.launchpad.net/widelands/+bug/1530240
  Bug #1530398 in widelands: "Wrong text above marble mine"
  https://bugs.launchpad.net/widelands/+bug/1530398
  Bug #1547909 in widelands: "Some strings in the editor cannot be translated"
  https://bugs.launchpad.net/widelands/+bug/1547909

For more details, see:
https://code.launchpad.net/~widelands-dev/widelands/string-fixes/+merge/345000
-- 
Your team Widelands Developers is requested to review the proposed merge of lp:~widelands-dev/widelands/string-fixes into lp:widelands.
=== modified file 'data/tribes/buildings/productionsites/frisians/blacksmithy/init.lua'
--- data/tribes/buildings/productionsites/frisians/ironmine/helptexts.lua	2018-04-25 07:55:28 +0000
+++ data/tribes/buildings/productionsites/frisians/ironmine/helptexts.lua	2018-05-03 05:43:13 +0000
@@ -1,15 +1,18 @@
+-- This include can be removed when all help texts have been defined.
+include "tribes/scripting/help/global_helptexts.lua"
+
 function building_helptext_lore ()
-   -- TRANSLATORS: Lore helptext for a building
-   return pgettext ("frisians_building", "")
+   -- TRANSLATORS#: Lore helptext for a building
+   return no_lore_text_yet()
 end
 
 function building_helptext_lore_author ()
-   -- TRANSLATORS: Lore author helptext for a building
-   return pgettext ("frisians_building", "")
+   -- TRANSLATORS#: Lore author helptext for a building
+   return no_lore_author_text_yet()
 end
 
 function building_helptext_purpose()
-   -- TRANSLATORS#: Purpose helptext for a building
+   -- TRANSLATORS: Purpose helptext for a building
    return pgettext("building", "Digs iron ore out of the ground in mountain terrain.")
 end
 

=== modified file 'data/tribes/buildings/productionsites/frisians/reed_farm/init.lua'
--- data/tribes/buildings/productionsites/frisians/reed_farm/init.lua	2018-02-23 07:18:54 +0000
+++ data/tribes/buildings/productionsites/frisians/reed_farm/init.lua	2018-05-03 05:43:13 +0000
@@ -79,7 +79,7 @@
       -- Translators: Short for "Out of ..." for a resource
       title = _"No Fields",
       heading = _"Out of Fields",
-      message = pgettext("frisians_building", "The farmer working at this reed farm has no cleared soil to plant his seeds."),
+      message = pgettext("frisians_building", "The reed farmer working at this reed farm has no cleared soil to plant his seeds."),
       productivity_threshold = 20
    },
 }

=== modified file 'data/tribes/buildings/productionsites/frisians/rockmine/helptexts.lua'
--- data/tribes/buildings/productionsites/frisians/rockmine/helptexts.lua	2018-04-25 07:55:28 +0000
+++ data/tribes/buildings/productionsites/frisians/rockmine/helptexts.lua	2018-05-03 05:43:13 +0000
@@ -1,11 +1,14 @@
+-- This include can be removed when all help texts have been defined.
+include "tribes/scripting/help/global_helptexts.lua"
+
 function building_helptext_lore ()
-   -- TRANSLATORS: Lore helptext for a building
-   return pgettext ("frisians_building", "")
+   -- TRANSLATORS#: Lore helptext for a building
+   return no_lore_text_yet()
 end
 
 function building_helptext_lore_author ()
-   -- TRANSLATORS: Lore author helptext for a building
-   return pgettext ("frisians_building", "")
+   -- TRANSLATORS#: Lore author helptext for a building
+   return no_lore_author_text_yet()
 end
 
 function building_helptext_purpose()

=== modified file 'data/tribes/buildings/productionsites/frisians/tavern/helptexts.lua'
--- data/tribes/buildings/productionsites/frisians/tavern/helptexts.lua	2018-02-17 15:41:29 +0000
+++ data/tribes/buildings/productionsites/frisians/tavern/helptexts.lua	2018-05-03 05:43:13 +0000
@@ -20,5 +20,5 @@
 
 function building_helptext_performance()
    -- TRANSLATORS#: Performance helptext for a building
-   return pgettext("frisians_building", "The tavern can produce one ration in %s on average if the supply is steady; otherwise, it will take 50 percent longer."):bformat(ngettext("%d second", "%d seconds", 33):bformat(33))
+   return pgettext("frisians_building", "The tavern can produce one ration in %s on average if the supply is steady; otherwise, it will take 50%% longer."):bformat(ngettext("%d second", "%d seconds", 33):bformat(33))
 end

=== modified file 'data/tribes/buildings/productionsites/frisians/weaving_mill/helptexts.lua'
--- data/tribes/buildings/productionsites/frisians/weaving_mill/helptexts.lua	2018-04-25 07:55:28 +0000
+++ data/tribes/buildings/productionsites/frisians/weaving_mill/helptexts.lua	2018-05-03 05:43:13 +0000
@@ -5,7 +5,7 @@
 
 function building_helptext_lore_author()
    -- TRANSLATORS: Lore author helptext for a building
-   return pgettext("frisians_building", "A seamstress’s work song")
+   return pgettext("frisians_building", "A seamstress’ work song")
 end
 
 function building_helptext_purpose()

=== modified file 'data/tribes/immovables/berry_bushes/strawberry/init.lua'
--- data/tribes/immovables/berry_bushes/strawberry/init.lua	2018-02-17 15:41:29 +0000
+++ data/tribes/immovables/berry_bushes/strawberry/init.lua	2018-05-03 05:43:13 +0000
@@ -10,7 +10,7 @@
 tribes:new_immovable_type {
    msgctxt = "immovable",
    name = "berry_bush_strawberry_tiny",
-   descname = _ "Strawberry Bush (tiny)",
+   descname = _ "Strawberries (tiny)",
    size = "small",
    helptext_script = dirname .. "helptexts.lua",
    attributes = { "seed_berrybush" },
@@ -34,7 +34,7 @@
 tribes:new_immovable_type {
    msgctxt = "immovable",
    name = "berry_bush_strawberry_small",
-   descname = _ "Strawberry Bush (small)",
+   descname = _ "Strawberries (small)",
    size = "small",
    helptext_script = dirname .. "helptexts.lua",
    attributes = {},
@@ -58,7 +58,7 @@
 tribes:new_immovable_type {
    msgctxt = "immovable",
    name = "berry_bush_strawberry_medium",
-   descname = _ "Strawberry Bush (medium)",
+   descname = _ "Strawberries (medium)",
    size = "small",
    helptext_script = dirname .. "helptexts.lua",
    attributes = { "flowering" },
@@ -82,7 +82,7 @@
 tribes:new_immovable_type {
    msgctxt = "immovable",
    name = "berry_bush_strawberry_ripe",
-   descname = _ "Strawberry Bush (ripe)",
+   descname = _ "Strawberries (ripe)",
    size = "small",
    helptext_script = dirname .. "helptexts.lua",
    attributes = { "ripe_bush" },

=== modified file 'data/tribes/wares/fur/helptexts.lua'
--- data/tribes/wares/fur/helptexts.lua	2017-08-19 16:02:04 +0000
+++ data/tribes/wares/fur/helptexts.lua	2018-05-03 05:43:13 +0000
@@ -1,7 +1,7 @@
 function ware_helptext(tribe)
    local helptext = {
       -- TRANSLATORS: Helptext for a ware: Fur
-      frisians = pgettext("frisians_ware", "Fur is won from reindeer in a reindeer farm. It is spun into cloth or turned into fur garments for soldiers."),
+      frisians = pgettext("frisians_ware", "Fur is won from reindeer in a reindeer farm. It is woven into cloth or turned into fur garments for soldiers."),
    }
    local result = ""
    if tribe then

=== modified file 'data/tribes/wares/granite/helptexts.lua'
--- data/tribes/wares/granite/helptexts.lua	2017-06-27 16:18:40 +0000
+++ data/tribes/wares/granite/helptexts.lua	2018-05-03 05:43:13 +0000
@@ -7,7 +7,7 @@
       -- TRANSLATORS: Helptext for a ware: Granite
       barbarians = pgettext("barbarians_ware", "The Barbarians produce granite blocks in quarries and granite mines."),
       -- TRANSLATORS: Helptext for a ware: Granite
-      frisians = pgettext("frisians_ware", "The Frisians produce granite blocks in quarries and granite mines. They can be refined by a brick burner."),
+      frisians = pgettext("frisians_ware", "The Frisians produce granite blocks in quarries and rock mines. They can be refined by a brick burner."),
       -- TRANSLATORS: Helptext for a ware: Granite
       empire = pgettext("empire_ware", "The Empire produces granite blocks in quarries and marble mines.")
    }

=== modified file 'data/tribes/wares/kitchen_tools/helptexts.lua'
--- data/tribes/wares/kitchen_tools/helptexts.lua	2018-02-17 15:48:54 +0000
+++ data/tribes/wares/kitchen_tools/helptexts.lua	2018-05-03 05:43:13 +0000
@@ -1,11 +1,11 @@
 function ware_helptext(tribe)
    local helptext = {
       -- TRANSLATORS: Helptext for a ware: Kitchen Tools
-      barbarians = pgettext("barbarians_ware", "How can one create a meal, snack or ration, if there are no kitchen tools? Be sure to have a metal workshop to produce this basic tool (but it ceases to be produced by the building if it is enhanced to an ax workshop and war mill)."),
-      -- TRANSLATORS: Helptext for a ware: Kitchen Tools
-      frisians = pgettext("frisians_ware", "How can one create a meal or ration, if there are no kitchen tools? The smoker also needs them."),
-      -- TRANSLATORS: Helptext for a ware: Kitchen Tools
-      empire = pgettext("empire_ware", "How can one create a ration or meal if there are no kitchen tools? They are produced in a toolsmithy and used in taverns and inns.")
+      barbarians = pgettext("barbarians_ware", "Kitchen tools are needed for preparing rations, snacks and meals. Be sure to have a metal workshop to produce this basic tool (but it ceases to be produced by the building if it is enhanced to an ax workshop and war mill)."),
+      -- TRANSLATORS: Helptext for a ware: Kitchen Tools
+      frisians = pgettext("frisians_ware", "Kitchen tools are needed for preparing rations and meals. The smoker also needs them."),
+      -- TRANSLATORS: Helptext for a ware: Kitchen Tools
+      empire = pgettext("empire_ware", "Kitchen tools are needed for preparing rations and meals. They are produced in a toolsmithy and used in taverns and inns.")
    }
    local result = ""
    if tribe then

=== modified file 'data/tribes/wares/ration/helptexts.lua'
--- data/tribes/wares/ration/helptexts.lua	2017-07-07 16:51:39 +0000
+++ data/tribes/wares/ration/helptexts.lua	2018-05-03 05:43:13 +0000
@@ -7,7 +7,7 @@
       -- TRANSLATORS: Helptext for a ware: Ration
       empire = pgettext("empire_ware", "Rations are produced in a tavern out of fish or meat or bread."),
       -- TRANSLATORS: Helptext for a ware: Ration
-      frisians = pgettext("frisians_ware", "They are produced in taverns and drinking halls out of beer and something to eat: Fruit, smoked meat or fish or bread.")
+      frisians = pgettext("frisians_ware", "Rations are produced in taverns and drinking halls out of beer and something to eat: Fruit, smoked meat or fish or bread.")
    }
    local result = ""
    if tribe then

=== modified file 'data/tribes/wares/shovel/helptexts.lua'
--- data/tribes/wares/shovel/helptexts.lua	2017-07-07 16:51:39 +0000
+++ data/tribes/wares/shovel/helptexts.lua	2018-05-03 05:43:13 +0000
@@ -9,7 +9,7 @@
       -- TRANSLATORS: Helptext for a ware: Shovel
       empire = pgettext("empire_ware", "Therefore the forester and the vine farmer use them. They are produced by the toolsmith."),
       -- TRANSLATORS: Helptext for a ware: Shovel
-      frisians = pgettext("frisians_ware", "They are used by berry and reed farmers as well as foresters. Diggers also need them to dig mud out of hard soil.")
+      frisians = pgettext("frisians_ware", "They are used by berry and reed farmers as well as foresters. Brickmakers also need them to dig mud out of hard soil.")
    }
    local result = ""
    if tribe then

=== modified file 'data/tribes/wares/smoked_fish/helptexts.lua'
--- data/tribes/wares/smoked_fish/helptexts.lua	2017-07-23 10:20:05 +0000
+++ data/tribes/wares/smoked_fish/helptexts.lua	2018-05-03 05:43:13 +0000
@@ -3,7 +3,7 @@
       -- TRANSLATORS: Helptext for a ware: Smoked Fish
       atlanteans = pgettext("atlanteans_ware", "As no Atlantean likes raw fish, smoking it in a smokery is the most common way to make it edible."),
       -- TRANSLATORS: Helptext for a ware: Smoked Fish
-      frisians = pgettext("frisians_ware", "Fish is smoked in a smokery. Smoked fish is then consumed by soldiers in training or turned into rations and meals for miners.")
+      frisians = pgettext("frisians_ware", "Fish is smoked in a smokery. Smoked fish is then consumed by soldiers in training or turned into rations and meals for miners and scouts.")
    }
    local result = ""
    if tribe then

=== modified file 'data/tribes/wares/smoked_meat/helptexts.lua'
--- data/tribes/wares/smoked_meat/helptexts.lua	2017-07-23 10:20:05 +0000
+++ data/tribes/wares/smoked_meat/helptexts.lua	2018-05-03 05:43:13 +0000
@@ -3,7 +3,7 @@
       -- TRANSLATORS: Helptext for a ware: Smoked Meat
       atlanteans = pgettext("atlanteans_ware", "Smoked meat is made out of meat in a smokery. It is delivered to the mines and training sites (labyrinth and dungeon) where the miners and soldiers prepare a nutritious lunch for themselves."),
       -- TRANSLATORS: Helptext for a ware: Smoked Meat
-      frisians = pgettext("frisians_ware", "Meat is smoked in a smokery. Smoked meat is then consumed by soldiers in training or turned into rations and meals for miners.")
+      frisians = pgettext("frisians_ware", "Meat is smoked in a smokery. Smoked meat is then consumed by soldiers in training or turned into rations and meals for miners and scouts.")
    }
    local result = ""
    if tribe then

=== modified file 'data/tribes/workers/barbarians/baker/helptexts.lua'
--- data/tribes/workers/barbarians/baker/helptexts.lua	2015-10-31 12:11:44 +0000
+++ data/tribes/workers/barbarians/baker/helptexts.lua	2018-05-03 05:43:13 +0000
@@ -1,4 +1,4 @@
 function worker_helptext()
    -- TRANSLATORS: Helptext for a worker: Baker
-   return pgettext("barbarians_worker", "Bakes pitta bread for the miners.")
+   return pgettext("barbarians_worker", "Bakes pitta bread for the miners, soldiers and scouts.")
 end

=== modified file 'data/tribes/workers/frisians/landlady/helptexts.lua'
--- data/tribes/workers/frisians/landlady/helptexts.lua	2017-07-07 16:51:39 +0000
+++ data/tribes/workers/frisians/landlady/helptexts.lua	2018-05-03 05:43:13 +0000
@@ -1,4 +1,4 @@
 function worker_helptext()
    -- TRANSLATORS: Helptext for a worker: Landlady
-   return pgettext("frisians_worker", "Prepares rations and meals for miners.")
+   return pgettext("frisians_worker", "Prepares rations and meals for miners and scouts.")
 end

=== modified file 'data/txts/developers.json'
--- data/txts/developers.json	2018-03-26 19:24:21 +0000
+++ data/txts/developers.json	2018-05-03 05:43:13 +0000
@@ -222,7 +222,7 @@
 			"image": "images/ui_basic/ls_wlmap.png",
 			"entries":[
 				{
-					"subheading": "Barbarian",
+					"subheading": "Barbarians",
 					"members":[
 						"Bastian Rapp",
 						"Alexander Kahl (wolfpac)",
@@ -237,14 +237,14 @@
 					]
 				},
 				{
-					"subheading": "Atlantean",
+					"subheading": "Atlanteans",
 					"members":[
 						"Holger Rapp (SirVer)",
 						"Peter Schwanemann (Nasenbaer)"
 					]
 				},
 				{
-					"subheading": "Frisian",
+					"subheading": "Frisians",
 					"members":[
 						"Benedikt Straub (Nordfriese)"
 					]


Follow ups
--- data/tribes/buildings/productionsites/frisians/blacksmithy/init.lua	2018-04-05 05:58:29 +0000
+++ data/tribes/buildings/productionsites/frisians/blacksmithy/init.lua	2018-05-03 05:43:13 +0000
@@ -211,8 +211,8 @@
          },
       },
       produce_12 = {
-         -- TRANSLATORS: Completed/Skipped/Did not start forging needles because ...
-         descname = _"forging needles",
+         -- TRANSLATORS: Completed/Skipped/Did not start making needles because ...
+         descname = _"making needles",
          actions = {
             "return=skipped unless economy needs needles",
             "sleep=32000",

=== modified file 'data/tribes/buildings/productionsites/frisians/ironmine/helptexts.lua'